@@ -5,12 +5,12 @@
  *  modify it under the terms of the GNU General Public License
  *  as published by the Free Software Foundation; either version 2
  *  of the License, or (at your option) any later version.
- * 
+ *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
- * 
+ *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
@@ -24,32 +24,23 @@
 
 G_BEGIN_DECLS
 
-#define RSTTO_TYPE_APP_MENU_ITEM            (rstto_app_menu_item_get_type())
-#define RSTTO_APP_MENU_ITEM(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), RSTTO_TYPE_APP_MENU_ITEM, RsttoAppMenuItem))
-#define RSTTO_APP_MENU_ITEM_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), RSTTO_TYPE_APP_MENU_ITEM, RsttoAppMenuItemClass))
-#define RSTTO_IS_APP_MENU_ITEM(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), RSTTO_TYPE_APP_MENU_ITEM))
-#define RSTTO_IS_APP_MENU_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), RSTTO_TYPE_APP_MENU_ITEM ()))
-#define RSTTO_APP_MENU_ITEM_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), RSTTO_TYPE_APP_MENU_ITEM, RsttoAppMenuItemClass))
+#define RSTTO_TYPE_APP_MENU_ITEM (rstto_app_menu_item_get_type ())
+G_DEFINE_AUTOPTR_CLEANUP_FUNC (GtkImageMenuItem, g_object_unref)
+G_DECLARE_FINAL_TYPE (RsttoAppMenuItem, rstto_app_menu_item, RSTTO, APP_MENU_ITEM, GtkImageMenuItem)
 
 typedef struct _RsttoAppMenuItemPrivate RsttoAppMenuItemPrivate;
 
-typedef struct _RsttoAppMenuItem RsttoAppMenuItem;
-
 struct _RsttoAppMenuItem
 {
     GtkImageMenuItem parent;
     RsttoAppMenuItemPrivate *priv;
 };
 
-typedef struct _RsttoAppMenuItemClass RsttoAppMenuItemClass;
 
-struct _RsttoAppMenuItemClass
-{
-    GtkImageMenuItemClass  parent_class;
-};
 
-GType       rstto_app_menu_item_get_type (void);
-GtkWidget  *rstto_app_menu_item_new (GAppInfo *app_info, GFile *file);
+GtkWidget *
+rstto_app_menu_item_new (GAppInfo *app_info,
+                         GFile *file);
 
 G_END_DECLS
 
