@@ -239,7 +239,8 @@ rstto_image_list_init (RsttoImageList *image_list)
 
     g_signal_connect (image_list->priv->thumbnailer, "ready",
                       G_CALLBACK (cb_rstto_thumbnailer_ready), image_list);
-
+    g_signal_connect (image_list->priv->thumbnailer, "error",
+                      G_CALLBACK (cb_rstto_thumbnailer_ready), image_list);
 }
 
 static void
@@ -322,6 +323,7 @@ rstto_image_list_add_file (RsttoImageList *image_list,
                            RsttoFile *r_file,
                            GError **error)
 {
+    RsttoImageListIter *r_iter;
     GtkTreePath *path;
     GtkTreeIter t_iter;
     GFileMonitor *monitor;
@@ -346,9 +348,15 @@ rstto_image_list_add_file (RsttoImageList *image_list,
 
     if (image_list->priv->dir_monitor == NULL)
     {
-        monitor = g_file_monitor_file (rstto_file_get_file (r_file), G_FILE_MONITOR_NONE, NULL, NULL);
-        g_signal_connect (monitor, "changed", G_CALLBACK (cb_file_monitor_changed), image_list);
-        image_list->priv->image_monitors = g_list_prepend (image_list->priv->image_monitors, monitor);
+        monitor = g_file_monitor_file (rstto_file_get_file (r_file),
+                                       G_FILE_MONITOR_WATCH_MOVES, NULL, NULL);
+        if (monitor != NULL)
+        {
+            g_signal_connect (monitor, "changed",
+                              G_CALLBACK (cb_file_monitor_changed), image_list);
+            image_list->priv->image_monitors =
+                g_list_prepend (image_list->priv->image_monitors, monitor);
+        }
     }
 
     path = gtk_tree_path_new ();
@@ -362,8 +370,16 @@ rstto_image_list_add_file (RsttoImageList *image_list,
     gtk_tree_path_free (path);
 
     for (iter = image_list->priv->iterators; iter != NULL; iter = iter->next)
-        if (! RSTTO_IMAGE_LIST_ITER (iter->data)->priv->sticky)
+    {
+        r_iter = iter->data;
+        if (! r_iter->priv->sticky)
+        {
             rstto_image_list_iter_find_file (iter->data, r_file);
+            r_iter->priv->sticky = TRUE;
+        }
+        else
+            rstto_image_list_iter_find_file (r_iter, r_iter->priv->r_file);
+    }
 
     return TRUE;
 }
@@ -427,30 +443,32 @@ rstto_image_list_remove_file (RsttoImageList *image_list,
             continue;
 
         if (r_iter->priv->link == image_list->priv->images->tail)
-            iter_previous (r_iter, r_iter->priv->sticky);
+            iter_previous (r_iter, FALSE);
         else
-            iter_next (r_iter, r_iter->priv->sticky);
-
-        /* if the image is still the same, it's a single item list,
-         * and we should force the image in this iter to NULL */
-        if (r_iter->priv->r_file == r_file)
-        {
-            r_iter->priv->r_file = NULL;
-            r_iter->priv->link = NULL;
-            r_iter->priv->index = -1;
-            g_signal_emit (r_iter,
-                           rstto_image_list_iter_signals[RSTTO_IMAGE_LIST_ITER_SIGNAL_CHANGED],
-                           0, NULL);
-        }
+            iter_next (r_iter, FALSE);
     }
 
-    g_queue_remove (image_list->priv->images, r_file);
-    g_object_unref (r_file);
+    if (image_list->priv->images->length == 1)
+    {
+        rstto_image_list_remove_all (image_list);
+        return;
+    }
+    else
+    {
+        g_queue_remove (image_list->priv->images, r_file);
+        g_object_unref (r_file);
+    }
 
     path_ = gtk_tree_path_new ();
     gtk_tree_path_append_index (path_, index_);
     gtk_tree_model_row_deleted (GTK_TREE_MODEL (image_list), path_);
     gtk_tree_path_free (path_);
+
+    for (iter = image_list->priv->iterators; iter != NULL; iter = iter->next)
+    {
+        r_iter = iter->data;
+        rstto_image_list_iter_find_file (r_iter, r_iter->priv->r_file);
+    }
 }
 
 static void
@@ -734,6 +752,7 @@ cb_file_monitor_changed (
     switch (event_type)
     {
         case G_FILE_MONITOR_EVENT_DELETED:
+        case G_FILE_MONITOR_EVENT_MOVED_OUT:
             rstto_image_list_remove_file (image_list, r_file);
             if (image_list->priv->dir_monitor == NULL)
             {
@@ -777,6 +796,13 @@ cb_file_monitor_changed (
         case G_FILE_MONITOR_EVENT_CHANGED:
             /* wait for DONE_HINT to update the image, so that we can get its mime type */
             break;
+        case G_FILE_MONITOR_EVENT_RENAMED:
+            cb_file_monitor_changed (monitor, file, other_file,
+                                     G_FILE_MONITOR_EVENT_DELETED, user_data);
+            g_object_unref (r_file);
+            r_file = rstto_file_new (other_file);
+            rstto_image_list_add_file (image_list, r_file, NULL);
+            break;
         default:
             break;
     }
@@ -881,7 +907,6 @@ rstto_image_list_iter_find_file (
     iter->priv->r_file = r_file;
     iter->priv->index = index;
     iter->priv->link = g_queue_peek_nth_link (image_list->priv->images, iter->priv->index);
-    iter->priv->sticky = TRUE;
 
     g_signal_emit (iter,
                    rstto_image_list_iter_signals[RSTTO_IMAGE_LIST_ITER_SIGNAL_CHANGED],
@@ -960,18 +985,19 @@ iter_next (
     {
         if (iter->priv->link->next != NULL)
         {
+            ret_val = TRUE;
             iter->priv->link = iter->priv->link->next;
             iter->priv->index++;
         }
         else
         {
+            ret_val = image_list->priv->images->length > 1;
             iter->priv->link = image_list->priv->images->head;
             iter->priv->index = 0;
         }
 
         iter->priv->r_file = iter->priv->link->data;
         iter->priv->sticky = sticky;
-        ret_val = TRUE;
     }
 
     if (ret_val == TRUE)
@@ -1018,18 +1044,19 @@ iter_previous (
     {
         if (iter->priv->link->prev != NULL)
         {
+            ret_val = TRUE;
             iter->priv->link = iter->priv->link->prev;
             iter->priv->index--;
         }
         else
         {
+            ret_val = image_list->priv->images->length > 1;
             iter->priv->link = image_list->priv->images->tail;
             iter->priv->index = image_list->priv->images->length - 1;
         }
 
         iter->priv->r_file = iter->priv->link->data;
         iter->priv->sticky = sticky;
-        ret_val = TRUE;
     }
 
     if (ret_val == TRUE)
