@@ -20,6 +20,7 @@
 #include "util.h"
 #include "file.h"
 #include "properties_dialog.h"
+#include "thumbnailer.h"
 
 
 
@@ -248,6 +249,31 @@ rstto_properties_dialog_get_property (
 {
 }
 
+static gboolean
+properties_dialog_set_icon (
+        RsttoThumbnailer *thumbnailer,
+        RsttoFile *file,
+        RsttoPropertiesDialog *dialog)
+{
+    const GdkPixbuf *pixbuf;
+
+    if (file != dialog->priv->file)
+        return FALSE;
+
+    pixbuf = rstto_file_get_thumbnail (file, RSTTO_THUMBNAIL_SIZE_VERY_LARGE);
+    if (pixbuf != NULL)
+    {
+        gint scale_factor = gtk_widget_get_scale_factor (GTK_WIDGET (dialog));
+        cairo_surface_t *surface = gdk_cairo_surface_create_from_pixbuf (pixbuf, scale_factor, NULL);
+        gtk_image_set_from_surface (GTK_IMAGE (dialog->priv->image_thumbnail), surface);
+        cairo_surface_destroy (surface);
+
+        return TRUE;
+    }
+
+    return FALSE;
+}
+
 static void
 properties_dialog_set_file (
         RsttoPropertiesDialog *dialog,
@@ -259,8 +285,6 @@ properties_dialog_set_file (
     gchar   buf[20];
     guint64 size;
 
-    const GdkPixbuf *pixbuf;
-
     ExifEntry   *exif_entry = NULL;
     ExifIfd      exif_ifd;
     const gchar *exif_title = NULL;
@@ -281,11 +305,13 @@ properties_dialog_set_file (
 
     if (dialog->priv->file)
     {
-        size = rstto_util_get_thumbnail_size (RSTTO_THUMBNAIL_FLAVOR_LARGE);
-        pixbuf = rstto_file_get_thumbnail (file, size);
-        if (NULL != pixbuf)
-            gtk_image_set_from_pixbuf (GTK_IMAGE (dialog->priv->image_thumbnail),
-                                       (GdkPixbuf *) pixbuf);
+        if (! properties_dialog_set_icon (NULL, file, dialog))
+        {
+            RsttoThumbnailer *thumbnailer = rstto_thumbnailer_new ();
+            g_signal_connect_object (thumbnailer, "ready",
+                                     G_CALLBACK (properties_dialog_set_icon), dialog, 0);
+            g_object_unref (thumbnailer);
+        }
 
         g_file = rstto_file_get_file (file);
         file_info = g_file_query_info (
