@@ -47,6 +47,10 @@ struct _RsttoSettings
 
 
 
+gboolean rstto_settings_get_xfconf_disabled (void);
+
+void rstto_settings_set_xfconf_disabled (gboolean disabled);
+
 RsttoSettings *rstto_settings_new (void);
 
 void
